%% WTP Plots

% "Addressing empirical challenges related to the incentive compatibility of stated preference methods"
%  Mikoaj Czajkowski, Christian A. Vossler , Wiktor Budziski, Aleksandra Winiewska and Ewa Zawojska

clear
clc
rng(179424673);

tic

load('teatry10out.mat')
DATA = load('TEATR_dane_02.mat');

% Number of repetitions in simulation
n = 100000;
bmtx = mvnrnd(Results.HMXL_d.bhat(1:38), Results.HMXL_d.ihess(1:38,1:38), n); 


LV = -2:0.1:2;
WTP_cons = zeros(5,3, length(LV));
WTP_vis = zeros(5,3, length(LV));

for i = 1:length(LV)
   WTP_cons(:,1,i) = 100*mean(bmtx(:, 1:5) + bmtx(:, 19:23)*LV(i),1)';
   WTP_cons(:,2,i) = 100*prctile(bmtx(:, 1:5) + bmtx(:, 19:23)*LV(i),2.5)';
   WTP_cons(:,3,i) = 100*prctile(bmtx(:, 1:5) + bmtx(:, 19:23)*LV(i),97.5)';
   
   WTP_vis(:,1,i) = 100*mean(bmtx(:, 1:5) + bmtx(:, 25:29)*LV(i),1)';
   WTP_vis(:,2,i) = 100*prctile(bmtx(:, 1:5) + bmtx(:, 25:29)*LV(i),2.5)';
   WTP_vis(:,3,i) = 100*prctile(bmtx(:, 1:5) + bmtx(:, 25:29)*LV(i),97.5)';
   
end

WTP_cons = permute(WTP_cons, [1 3 2]);
WTP_vis = permute(WTP_vis, [1 3 2]);

LV_norm = normcdf(LV);
xi = 0.025:0.01:0.975;
Names = Results.HMXL_d.EstimOpt.NamesA;

for i = 1:5
        figure;
        set(gcf,'color','w');
        hold all
        mi = interp1(LV_norm,WTP_cons(i,:,1),xi,'pchip');
        q1i = interp1(LV_norm,WTP_cons(i,:,2),xi,'pchip');
        q2i = interp1(LV_norm,WTP_cons(i,:,3),xi,'pchip');
        plot(xi,mi,'b-');
        plot(xi,q1i,'b--');
        plot(xi,q2i,'b--');
        set(gca,'FontName','cmr12')
        set(gca,'XTick',[0.025,0.25,0.5,0.75,0.975],'XTickLabel',{'bottom\newline 2.25%','bottom\newline  25%','population\newline   mean','  top\newline 25%', '   top\newline 2.25%'});
        set(gca,'Position',[.05 .1 .93 .87])
        saveas(gcf,[char(Names(i)), ' - Cons'],'png')
end

for i = 1:5
        figure;
        set(gcf,'color','w');
        hold all
        mi = interp1(LV_norm,WTP_vis(i,:,1),xi,'pchip');
        q1i = interp1(LV_norm,WTP_vis(i,:,2),xi,'pchip');
        q2i = interp1(LV_norm,WTP_vis(i,:,3),xi,'pchip');
        plot(xi,mi,'b-');
        plot(xi,q1i,'b--');
        plot(xi,q2i,'b--');
        set(gca,'FontName','cmr12')
        set(gca,'XTick',[0.025,0.25,0.5,0.75,0.975],'XTickLabel',{'bottom\newline 2.25%','bottom\newline  25%','population\newline   mean','  top\newline 25%', '   top\newline 2.25%'});
        set(gca,'Position',[.05 .1 .93 .87])
        saveas(gcf,[char(Names(i)), ' - vis'],'png')
end

toc