% Theater study - consequentiality
% Mikolaj Czajkowski, miq@wne.uw.edu.pl, 2017-06-27

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.fnameinput = ('theater_data.mat');
DATA = load(EstimOpt.fnameinput);

% coneq - perceived consequentiality (1-5, high = consequential)
% vcons - version of consequentiality (1-4 - wersja z rn iloci informacji)

DATA.SQ = DATA.ALT == 1;

DATA.VCONS = dummyvar(DATA.vcons);
DATA.CONSEQ = dummyvar(DATA.coneq);

DATA.vcons_norm = (DATA.vcons - mean(DATA.vcons))./std(DATA.vcons);

% education level (1-3)
DATA.edu1 = DATA.edugroup == 1;
DATA.edu2 = DATA.edugroup == 2;
DATA.edu3 = DATA.edugroup == 3;

DATA.age = 2014 - DATA.yearborn;
DATA.age_norm = DATA.age - mean(DATA.age);

DATA.HHc = DATA.havechildall - 1; % no of children (0-3)
DATA.HHc2 = DATA.HHc; % no of children (0-3)
DATA.HHc2(DATA.HHc2>0) = DATA.HHc2(DATA.HHc2>0) - 1;
DATA.HHcd = DATA.HHc > 0; % no of children > 0

DATA.female = DATA.sex - 1;

DATA.hinc0 = DATA.moneyhomec;
DATA.hinc0NaN = isnan(DATA.moneyhomec);
DATA.hinc = DATA.hinc0;
DATA.hinc0(DATA.hinc0NaN) = 0;
DATA.hinc0 = (DATA.hinc0 - mean(DATA.hinc0)) ./ std(DATA.hinc0);
DATA.hinc(isnan(DATA.hinc)) = nanmean(DATA.hinc);
DATA.hinc = (DATA.hinc - mean(DATA.hinc)) ./ std(DATA.hinc);

DATA.theatre12c_norm = DATA.theatre12c - mean(DATA.theatre12c);
DATA.theatre12c_norm = DATA.theatre12c_norm ./ std(DATA.theatre12c_norm);

DATA.theatre12c_log_norm = log(DATA.theatre12c+eps);
DATA.theatre12c_log_norm = DATA.theatre12c_log_norm - mean(DATA.theatre12c_log_norm);
DATA.theatre12c_log_norm = DATA.theatre12c_log_norm ./ std(DATA.theatre12c_log_norm);

DATA.theatre12c_2_norm = DATA.theatre12c_norm.^2 .* sign(DATA.theatre12c_norm);
DATA.theatre12c_2_norm = DATA.theatre12c_2_norm - mean(DATA.theatre12c_2_norm);
DATA.theatre12c_2_norm = DATA.theatre12c_2_norm ./ std(DATA.theatre12c_2_norm);

DATA.theatre12c_log0 = DATA.theatre12c;
DATA.theatre12c_log0(DATA.theatre12c_log0>0) = log(DATA.theatre12c_log0(DATA.theatre12c_log0>0));

% protests:
% would not pay:
dstats(DATA.readytax,1); % 29.76%
% consistently choose SQ:
DATA.allwaysSQ = repmat(sum(reshape(DATA.SQ(DATA.ANS==1),[12,1700]),1)'==12,[1,12*2])';
DATA.allwaysSQ = DATA.allwaysSQ(:);
% dstats(DATA.allwaysSQ,1) % 16.18%
% dstats(DATA.allwaysSQ==1 & DATA.readytax==2,1) % 12.47%

% dstats(DATA.motwaste == 1 | DATA.motwaste == 2,1) % uwa?am, ?e pieni?dze zostan? zmarnowane
% dstats(DATA.mottax == 1 | DATA.mottax == 2,1) % jestem przeciwny wprowadzaniu jakichkolwiek nowych podatkw
% dstats(DATA.motposs == 1 | DATA.mottax == 2,1) % pieni?dze podatknikw w Polsce s? generalnie ?le wydawane
% dstats(DATA.moteffort ~= 1 & DATA.mottax ~= 2,1) % ~nie mg?bym sobie pozwoli? na p?acenie wy?szych podatkw

DATA.protest_motive = ((DATA.motwaste == 1 | DATA.motwaste == 2) | (DATA.mottax == 1 | DATA.mottax == 2) | (DATA.motposs == 1 | DATA.mottax == 2)) & (DATA.moteffort ~= 1 & DATA.mottax ~= 2);
% dstats(DATA.protest_motive,1) % 28.12%

DATA.protest = (DATA.allwaysSQ==1) & (DATA.readytax==2) & (DATA.protest_motive);
% dstats(DATA.protest,1) % 3.47%


DATA.X = [DATA.SQ DATA.ROZ DATA.SRO DATA.DZI DATA.EKS -DATA.COST/100];
EstimOpt.NamesA = {'Status quo';'Entertainment theatres'; 'Drama theatres'; 'Children''s theatres'; 'Experimental theatres'; 'Cost (scale)'};


%% ****************************  model specification  ****************************

DATA.filter = true(size(DATA.ANS));
% DATA.filter = DATA.protest ~= 1;


INPUT.Y = DATA.ANS(DATA.filter);
INPUT.Xa = DATA.X(DATA.filter,:);

EstimOpt.WTP_space = 1;

% 1.0:
EstimOpt.NLatent = 2;
INPUT.Xmea = [DATA.coneq(DATA.filter), DATA.theatre12c(DATA.filter)];%, DATA.dotall, DATA.dotnotall, DATA.dotcheap, DATA.dotart, DATA.dotedu, DATA.dotcul, DATA.dotexclus, DATA.dotwaste, DATA.motwanturb, DATA.motwantall, DATA.motposs, DATA.motwaste, DATA.moteffort, DATA.mottax, DATA.motculture];
EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};%, 'dotall', 'dotnotall', 'dotcheap', 'dotart', 'dotedu', 'dotcul', 'dotexclus', 'dotwaste', 'motwanturb', 'motwantall', 'motposs', 'motwaste', 'moteffort', 'mottax', 'motculture'};
EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1)];
EstimOpt.MeaSpecMatrix = [2 3];
INPUT.Xm = [DATA.vcons_norm(DATA.filter)];%, DATA.theatre12c > 0, DATA.theatre12c_log0]; %DATA.theatre12c_norm
EstimOpt.NamesM = {'obj. cons. (norm.)'};%,'theater visits > 0','log(theater visits 0+)'}; %'theater visits norm.'
INPUT.Xmea_exp = [DATA.vcons_norm(DATA.filter)];%, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0]; % DATA.theatre12c_norm
EstimOpt.NamesMeaExp = {'obj. cons. (norm.)'};%, 'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'}; %'theater visits norm.',

% 1.1:
% EstimOpt.NLatent = 1;
% INPUT.Xmea = [DATA.coneq];
% EstimOpt.NamesMea = {'Stated cons.'};
% EstimOpt.MeaSpecMatrix = [2];
% INPUT.Xm = [DATA.vcons_norm, DATA.theatre12c > 0, DATA.theatre12c_log0];
% EstimOpt.NamesM = {'obj. cons. (norm.)','theater visits > 0','log(theater visits 0+)'};
% INPUT.Xmea_exp = [DATA.vcons_norm];%, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0]; % DATA.theatre12c_norm
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)'};%, 'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'}; %'theater visits norm.',

% 1.3:
% EstimOpt.NLatent = 2;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 1 ones(1,size(INPUT.Xmea,2)-1)];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)'};

% 1.4:
% EstimOpt.NLatent = 2;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1)];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm,DATA.theatre12c > 0, DATA.theatre12c_log0];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','theater visits > 0','log(theater visits 0+)'};

% 2.0:
% EstimOpt.NLatent = 2;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];%, DATA.dotall, DATA.dotnotall, DATA.dotcheap, DATA.dotart, DATA.dotedu, DATA.dotcul, DATA.dotexclus, DATA.dotwaste, DATA.motwanturb, DATA.motwantall, DATA.motposs, DATA.motwaste, DATA.moteffort, DATA.mottax, DATA.motculture];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};%, 'dotall', 'dotnotall', 'dotcheap', 'dotart', 'dotedu', 'dotcul', 'dotexclus', 'dotwaste', 'motwanturb', 'motwantall', 'motposs', 'motwaste', 'moteffort', 'mottax', 'motculture'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1)];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];%, DATA.theatre12c > 0, DATA.theatre12c_log0]; %DATA.theatre12c_norm
% EstimOpt.NamesM = {'obj. cons. (norm.)'};%,'theater visits > 0','log(theater visits 0+)'}; %'theater visits norm.'
% INPUT.Xmea_exp = [DATA.vcons_norm, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0]; % DATA.theatre12c_norm
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'}; %'theater visits norm.',

% 2.1:
% EstimOpt.NLatent = 3;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1); zeros(EstimOpt.NLatent-2,size(INPUT.Xmea,2))];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% INPUT.Xstr = [DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesStr = {'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% EstimOpt.StrMatrix = [0;0;ones(EstimOpt.NLatent-2,1)];

% 2.2:
% EstimOpt.NLatent = 4;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1); zeros(EstimOpt.NLatent-2,size(INPUT.Xmea,2))];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% INPUT.Xstr = [DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesStr = {'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% EstimOpt.StrMatrix = [0;0;ones(EstimOpt.NLatent-2,1)];

% 2.3:
% EstimOpt.NLatent = 5;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1); zeros(EstimOpt.NLatent-2,size(INPUT.Xmea,2))];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% INPUT.Xstr = [DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesStr = {'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% EstimOpt.StrMatrix = [0;0;ones(EstimOpt.NLatent-2,1)];

% 2.4:
% EstimOpt.NLatent = 6;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1); zeros(EstimOpt.NLatent-2,size(INPUT.Xmea,2))];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% INPUT.Xstr = [DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesStr = {'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% EstimOpt.StrMatrix = [0;0;ones(EstimOpt.NLatent-2,1)];

% 2.5:
% EstimOpt.NLatent = 7;
% INPUT.Xmea = [DATA.coneq, DATA.theatre12c];
% EstimOpt.NamesMea = {'Stated cons.', 'No of visits'};
% EstimOpt.MeaMatrix = [1 zeros(1,size(INPUT.Xmea,2)-1); 0 ones(1,size(INPUT.Xmea,2)-1); zeros(EstimOpt.NLatent-2,size(INPUT.Xmea,2))];
% EstimOpt.MeaSpecMatrix = [2 3];
% INPUT.Xm = [DATA.vcons_norm];
% EstimOpt.NamesM = {'obj. cons. (norm.)'};
% INPUT.Xmea_exp = [DATA.vcons_norm, DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesMeaExp = {'obj. cons. (norm.)','female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% INPUT.Xstr = [DATA.sex,DATA.age,DATA.age.^2,DATA.edu==3,DATA.edu==4,DATA.edu==5,DATA.edu==6,DATA.nrmem,DATA.nrmem.^2,DATA.HHc, DATA.hinc0NaN, DATA.hinc0];
% EstimOpt.NamesStr = {'female','age','age^2','edu vocc.','edu A-level','edu secondary','higher','HH size','HH size^2','no. of children','HH income NaN','HH income'};
% EstimOpt.StrMatrix = [0;0;ones(EstimOpt.NLatent-2,1)];


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 12; % Number of choice tasks per person
EstimOpt.NAlt = 2; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt;


%% **************************** estimation and optimization options ****************************


% EstimOpt.eps = 1.e-12; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1; % maximum number of iterations
% OptimOpt.Algorithm = 'trust-region'; %'quasi-newton'; % 'trust-region'
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 0; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian

% EstimOpt.DRAWSkeep = 1;


% EstimOpt.RealMin = 0;
% 
% EstimOpt.Dist = zeros(1,EstimOpt.NVarA);
% EstimOpt.Dist(end-EstimOpt.WTP_space+1:end) = 1;
% EstimOpt.MNLDist = EstimOpt.Dist;


% Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);

% EstimOpt.Dist = [1 EstimOpt.Dist];
% Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);
% EstimOpt.Dist = EstimOpt.Dist(2:end);
%     Results.MXL_d.bhat = [0.0607166292821921;0.320449782989805;0.212739730223666;0.106743182950199;0.0972966626613947;2.09610585830370;0.531871326929538;0.306701791701310;0.211953350464732;0.182112634291062;0.197934054323640;-1.06383964193198;0.0296450332462980;0.0237233490999985;0.0283231172141291;0.00410826343173916;-0.00412518534117009;-0.156476773833443];


%     Results.HMNL = HMNL(INPUT,Results,EstimOpt,OptimOpt);
% xlswrite('HMNL_model_1.xls', Results.HMNL.R_out)


%% *************************** HMXL ********************************

% 1.0: -15035.9606
% Results.HMXL_d.b0 = [0.0189232543622174;0.330707597128294;0.210683990896005;0.107466830406191;0.0991407015931294;2.16403682705127;0.439886139872505;0.0548596607864541;0.114989928320489;0.156160852692670;0.166448798547161;-1.03465995227678;0.0260210048870554;0.0334284813504693;0.0336067378124943;0.00575481068715466;-0.00292627290079279;-0.153773199889678;0.000489796873301773;0.302626536268972;0.173233144468788;0.0382613045850209;0.0905785972422256;-0.494791087010370;-0.0962670132572399;0.0864564698497901;0.0535373175406202;0.00885303168631443;0.0478322108287238;-0.246470657408972;0.151787295513961;-0.0299278506608686;-1.61267717119208;-0.130997967290878;0.301911767468623;-0.0302528978316574;0.800718061920848;0.782225239779492;0];
% 1.0 @R2017b: -15037.7129
Results.HMXL_d.b0 = [0.0165514045154225;0.328313435278694;0.210041863730912;0.107392860402014;0.0975172378311125;2.17620480502058;0.439506957244791;0.0575121957140861;0.111782628966492;0.156044289909869;0.165861471054606;-1.05819187346159;0.0252169977524144;0.0321295142685734;0.0329906171337335;0.00664876511858157;-0.00223831953831553;-0.154825192665665;-0.00655321619110690;0.302498746692827;0.181649654992705;0.0333066892876067;0.0911113457173375;-0.498963547639273;-0.0965235687016953;0.0840858871655163;0.0508935175753300;0.00870817013166642;0.0476450367210529;-0.243252649055722;0.153172817915753;-0.0303486771531119;-1.61460130639890;-0.128600959034977;0.302463534360425;-0.0295911654879895;0.799967875490240;0.783001069310531;0];
% 1.0 @R2017b with protest responses removed: 
% Results.HMXL_d.b0 = [0.00214348588377472;0.339391772981438;0.216140780530835;0.110155233805697;0.102508461398186;2.13541147136287;0.422717279023847;0.0427062962092987;0.126454195870370;0.182967002172971;0.165369966460468;-1.03968581572490;0.0184432373465106;0.0310840112807495;0.0293951009886549;0.00260656421323364;-0.00312415794557603;-0.148349596801222;0.00939945716103603;0.297804968456495;0.165052843272709;0.0398264539966406;0.0903264802967611;-0.416409384704373;-0.0764034275274557;0.0819327915630546;0.0476744502187842;0.0153337818058149;0.0494772930879671;-0.267198779980591;0.138139171154655;-0.0338292607478091;-1.63790036717913;-0.131885827561460;0.314855563674895;-0.0308359852011649;0.798929723551761;0.778116432126811;0];
EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
EstimOpt.BActive(end) = 0;
Results.HMXL_d.b0 = Results.HMXL_d.b0.*EstimOpt.BActive;

% 1.1: -11226.3728
%     Results.HMXL_d.b0 = [0.179825440949523;0.205125389866410;0.153187623661723;0.0923599700782361;0.0281466573963238;2.50541647591832;0.450670397062192;0.0412636374950502;-0.124976151717473;-0.172584216352749;-0.178751682003968;1.08345301470569;0.0140596667497378;0.0386981724490596;0.0348299261189933;0.00502876330914060;0.00379479165356203;-0.163847079985042;-0.121951982739505;0.0936013359898028;0.0288019883769817;0.0227066095368958;0.0537060769146351;-0.144848156528269;-0.0599754096565584;0.0598905873248978;0.0454141438164639;-0.00315801375956791;0.0304808819885247;-0.207093800951437;-0.00512117753541220;0.305772738941599;0.166326319370668;0.0265214994405133;0.0916553511395475;-0.528524008742954;0.146683055616142;-0.0284540909019944;-1.61301515786747;-0.129687219442518;0.301565305279162;-0.0299729273369224];

% 1.2: -15030.0337
%     Results.HMXL_d.b0 = [-0.0235602241472476;0.284045840832752;0.167319749832283;0.122190903663579;0.0942763532910895;2.43194562984403;0.424913116847470;0.0443360710733412;0.101897699772461;0.159568625297345;0.168466514535511;-1.06134097232401;0.0686995440048061;0.0185062024802143;0.0283315783830297;-0.0501632970252812;0.0115540427515850;-0.153563358136438;0.0478468207587787;0.0554814653848734;0.0536598957328729;-0.0281162341918628;0.0151052091977740;-0.299890420229239;0.0777073073604284;0.104602561238413;0.0835185696099978;0.0106086940608926;-0.00835360049795973;-0.448299755052958;-0.00768925037036258;0.315798739961823;0.176232293137857;0.0485645576485574;0.0858550437312194;-0.540074352422658;-0.0907262718241364;0.102054961678035;0.0534323043973539;0.00571416414723567;0.0562797214337080;-0.274686576348461;0.147010202618005;-0.0208488327556929;-0.0169450566561255;-0.0401197780439540;-1.61296546360870;-0.129382429394619;0.301580291460532;-0.0303417645831327;0.793440309036215;0.785446360889480;0;0;0];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-2:end) = 0;

% 1.3: -15030.5987
%     Results.HMXL_d.b0 = [0.0288804708530556;0.328803884098488;0.208909455436032;0.107667960350584;0.0978003280404648;2.20375307445232;0.437241614740588;0.0101128294552612;0.126360059419563;0.157205852929920;0.171152916223425;-1.06717592552648;0.0187037983021793;0.0324860202682324;0.0291260121596319;0.00229546048488524;-0.000120462368142227;-0.167877562076986;0.00925905209060151;0.305721762695601;0.161069998867318;0.0429266584657797;0.0829056261400546;-0.511704376740421;-0.110398539456435;0.109391651470945;0.0610625846986449;0.00522254648313777;0.0604511613110452;-0.283832023540129;0.133046289797040;0.101213534300617;-0.0308564840711355;-1.61423653369231;-0.130351440824268;0.304859879914925;-0.0250844698528416;0.794488529294458;0.787902963186585;0];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end) = 0;
%     Results.HMXL_d.b0 = Results.HMXL_d.b0.*EstimOpt.BActive;

% 1.4: -15030.4758
%     Results.HMXL_d.b0 = [0.0260027402473002;0.332008063916480;0.211606603487463;0.108372763250855;0.0998781181030380;2.20106808295643;0.435624008542508;0.00553612291071991;0.125855574999605;0.166300742005137;0.169221150296802;-1.05625758304787;0.0116914020765578;0.0357923654583059;0.0306526436680010;0.00273438424841462;0.00117522988425318;-0.173320011314049;0.0109156225351827;0.302112812041972;0.157790927311863;0.0360163139933469;0.0778022418808756;-0.509844660558976;-0.104319834982357;0.105540303225415;0.0642134646524595;0.00393945244982365;0.0575294156785618;-0.291970557296703;0.152050885049516;-0.0298634443420924;-0.00185401398635073;0.0773469899122825;-1.61724316107958;-0.128868877646142;0.305486466419560;-0.0251169613031711;0.797821522534045;0.786836795653154;0;0;0];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-2:end) = 0;
%     Results.HMXL_d.b0 = Results.HMXL_d.b0.*EstimOpt.BActive;

% 2.0: -14955.4685
%     Results.HMXL_d.b0 = [0.0276585903989216;0.328895800144042;0.209468812500475;0.106303687119599;0.0981353458016565;2.19772670915593;0.435926826716304;-0.000405080335089376;0.125955580862695;0.154757802614306;0.171941726218628;-1.05803543203768;0.0213258151027984;0.0310294778132192;0.0301130252864850;0.00394319708080685;-0.000512727320859848;-0.164616518241861;0.00986826810110051;0.301994657382934;0.160879736380943;0.0433332420944088;0.0842776412609878;-0.506993923792981;-0.119742386367398;0.105027308086152;0.0558591665352104;-0.00567404494186091;0.0620468883781281;-0.293081180548663;0.140732221827657;-0.0304254250834255;0.0190406557104454;0.219721072561645;-0.244976116848143;0.0793872338600943;0.128826941635894;0.0976091534935108;0.109136977483693;0.141715260327955;-0.106219610256012;-0.0437295049190488;0.00538850730249759;0.00280129958478991;-1.62295044770129;-0.121237439503850;0.306551127406715;-0.0299063867471057;0.790825296965863;0.743944100011374;0;0.0410112986672393;0.0699333026134672;-0.0184450101858853;-0.0115205746039218;0.0723444315794089;0.0751740882819155;0.236754902308620;0.100932570031946;-0.0848536573071190;0.0383327200123927;0.128865410691502;0.162018689402406];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-12) = 0;

% 2.1: -14898.1419
%     Results.HMXL_d.b0 = [0.0288893872259117;0.338603518965426;0.216936065434643;0.109442777792572;0.100576546762595;2.18861118252057;0.443988205434596;-0.0196490588559406;0.123529077090926;0.147256027374995;0.167475734402200;-1.05848584788696;0.00875170488236417;0.0318354499285418;0.0269341310508963;0.00948117418136491;0.00114061168120528;-0.163982625553535;0.0427079299833103;0.298815327924134;0.163690709667540;0.0471039691556774;0.0844934717558510;-0.501039267603734;-0.108081185987890;0.108437954714528;0.0555435097819034;-0.00763355812882143;0.0573753808049976;-0.271073096611576;-0.0631809718623212;0.00957322500365660;-0.0173072514605289;0.0791480274100256;0.00546715868289341;-0.0621753328801012;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;2.98383311765332;2.03119387184968;-1.12615801789116;1.50537469255920;1.06254595128304;-2.68577248500670;-2.25374125609900;-5.21154590324151;10.7876594676025;8.22175575320710;-0.813386679674729;4.15425836810418;0.131366144939375;-0.0296301870433327;0.0212380212632635;0.219339931096769;-0.244269307315349;0.0802704005696675;0.129955536076841;0.0962786026000351;0.108039076434023;0.141152040192655;-0.103310382326738;-0.0410186379114892;0.00453011752332274;0.00494867953657842;-1.62287718503119;-0.122292815442898;0.305328069096523;-0.0312136647902556;0.797935852554420;0.737598432901550;0;0.0510754257842869;0.0795958295455617;-0.0285325342315015;-0.00543609530138559;0.0692741298337127;0.0681769482791977;0.234811589228613;0.0719953940586650;-0.0427193875054471;0.0586833930958219;0.125742132419625;0.168371229354101];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-12) = 0;

% 2.2: -14875.6529
%     Results.HMXL_d.b0 = [0.0205763683113199;0.337873848863061;0.216162498896870;0.117941232250552;0.100749818852326;2.15770859538510;0.437784684090795;0.00417030129135242;-0.0879935401246999;-0.0102515996435604;0.160524171118185;-1.03911044628260;0.0153825223696934;0.0326156243767204;0.0313329632562659;0.00835488857403792;-0.00340123385736794;-0.149911268899361;0.0164937572673262;0.295666999025960;0.177954657586526;0.0646450445350165;0.0901734077069828;-0.533051898043639;-0.105793031236404;0.0934379429481312;0.0572893638594003;-0.00356761259275283;0.0444503376546860;-0.254261964256752;-0.00565122314802833;0.0587653368999666;0.0484660685351556;-0.152833590172111;0.0145371517645622;0.0672904712037808;-0.0479518202001973;0.0355685844807737;0.0117751559499815;0.0754364479519732;0.0286988623357687;-0.119513487015596;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0.257956821550202;-0.0727716371029926;-0.197751574821229;0.290444060290914;0.457159464866746;0.340575795714238;0.460384320605129;0.259551015120361;-0.208693643687571;-0.546343668556065;-0.0396143993124164;0.0712256623053381;1.68138336041334;-1.33476509955069;0.506709869777944;1.10088627892818;1.62950508534478;0.601505932275558;0.949596666354672;0.113386808170542;1.29544936027873;-0.227393098688186;-0.256031025658543;1.36029527701206;0.142184743675971;-0.0299417954698435;0.0272445755561332;0.212446939968201;-0.242984831204563;0.0855834263221781;0.138077778005800;0.101570959393002;0.115231479614374;0.145205692102726;-0.104393315856604;-0.0482962200596571;0.00436437046725564;0.00884198741052060;-1.62603754583440;-0.121067172066032;0.306559333855076;-0.0295503044183475;0.800040366603679;0.735546651853429;0;0.0738287978736759;0.0244368630104449;0.00814577724200196;0.0101711935599145;0.101881373365456;0.0874241588155353;0.259715030243977;0.115701954860231;-0.0743474482675719;0.0295943821678142;0.124048594525782;0.179431910921470];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-12) = 0;

% 2.3: -14850.6811
%     Results.HMXL_d.b0 = [0.0544892875187275;0.337225968551356;0.220817427552009;0.131761451927924;0.101576979625958;2.18460680080152;0.334912389780865;0.0987262618175255;0.0957242079240882;-0.0210783383809396;0.162980221896777;-0.837650004921928;0.0193072997656700;0.0351680015912753;0.0308036960938411;0.0104242908282151;-0.000887722423932332;-0.158263355219528;-0.222030958326567;0.164123719546770;0.0861413112926844;-0.0302296778697634;0.0768990852066057;0.137365471156887;-0.0946387019710458;0.0923309757514974;0.0494895551805125;-0.000702374120544326;0.0437534452649506;-0.290677374843334;0.129743969126012;0.240281469550615;0.164001849146095;0.138295674937977;0.0823576759124449;-0.903053417180918;-0.0465820288249015;-0.0599215331700291;-0.00843825055920919;-0.128432176746724;-0.0200660321106284;0.396312688371166;-0.150026572226054;-0.130514410185116;-0.0771916573615275;0.0773369599142172;-0.0292218509679951;0.324595050921299;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0.341037009390795;-0.0465577348657263;0.0828808009209184;0.119822466388437;0.118037195255153;0.0460145245255950;0.209944055910530;0.0233271369868696;0.370601957284770;-0.397317623656332;-0.163621130782299;0.160422011658973;0.660815332680632;1.19302212200846;-1.04208402376076;0.576906159072238;0.417400838855477;0.311887116261104;0.921640437515161;0.0522433459064042;0.667316108043336;-1.75757502785660;-0.417028944215879;0.0794445018755282;0.202929118908265;0.531863429599765;-0.356072515730869;0.103379412213183;-0.108743919128787;-0.218203515096113;-0.0637886350713206;-0.385318232459797;0.800005799128320;-0.0154496299607170;-0.141334556254267;0.178213546023390;0.208107784858760;-0.0296876800147810;0.0247657236930185;0.203717944791941;-0.227847370295497;0.0745538539944375;0.125177549443654;0.0986488925031892;0.109965123192069;0.149843155619655;-0.108129688019211;-0.0507579312039097;0.00318272982694806;0.00560921835059950;-1.64211887728789;-0.109662307853915;0.317382301032239;-0.0179021826476780;0.798144278265072;0.732495206264344;0;0.0666534476287706;0.0203251015821253;0.0257470487483124;-0.000885497287464547;0.0837467937860909;0.0816988546785210;0.249296083104212;0.104627626100196;-0.0577049215251577;0.0231312578234572;0.114685250853871;0.171489903124940];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-12) = 0;

% 2.4: -14834.2060
%     Results.HMXL_d.b0 = [0.0446585048081343;0.335238302469546;0.219983490284525;0.129626299729363;0.0948824212263282;2.21125804461823;0.362668007531857;0.0412718551995105;0.118791080276278;0.0671216416007949;0.111788455692268;-0.945031551406646;0.0157094996132845;0.0388374311199169;0.0347036962529984;0.0137385369313472;0.000778323670607409;-0.176269846590859;-0.0892623806698215;0.261017385603487;0.146319532343076;0.0566869689320118;0.139152264637598;-0.445072377024144;-0.0854404311793119;0.0895024270422169;0.0476334586528380;0.000340787017343976;0.0460794740921319;-0.278846617170097;0.230684673303792;-0.0207325996414406;0.0212012463527314;0.195902202282017;-0.0258315545229322;-0.748971394634037;0.614902812399655;0.387192313195962;0.297501436968813;-0.0459760577556657;-0.358307015214484;-1.34303297052201;-0.192070674808529;-0.107206664865438;-0.102628105493522;-0.0284216675458912;-0.0630806405067228;0.572142878856685;-0.527693804467738;-0.510290261560439;-0.353670852712728;0.0931137714268388;0.295713644603259;1.29156905851190;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0.303255140567789;0.233989635850240;-0.0395786816904097;-0.327180997497478;-0.329830035333896;-0.522582853851172;-0.680336149083670;-0.496490192345173;0.880650814767732;0.694232411528503;0.0574417574669982;0.408436959291487;-5.43770678164373;-1.85223335037590;1.53719525515864;0.259914094492300;-0.715202959087781;1.94238415917929;2.85601154322023;2.30115905576109;-6.33165908068990;-3.92374433622623;0.177146584718036;-4.40220821298085;0.183377744569322;1.75565212079081;-1.43128101793129;-0.491240503791339;-0.802127822187799;-1.04955999380790;-1.27259764346665;-0.749643531227781;1.08590626507869;0.639572554792306;0.348062355128706;0.456755096603855;-2.66535014823263;-1.38953658108881;1.15096310454243;0.527705003187471;0.113505902369610;1.33007100516603;1.96514974578269;1.00016309622758;-2.89112506431173;-1.72011559667639;-0.197526300255931;-2.23092585150493;0.154754690552273;-0.0278581509224478;0.0304813786036945;0.209542600109065;-0.237333087144203;0.0794360100824700;0.134065483248272;0.101702280277996;0.110531092000934;0.149782436391481;-0.110786830773220;-0.0447903065084668;0.00403191687049234;0.00876881428839535;-1.62700516553232;-0.120251658591363;0.308143252598632;-0.0267996886942737;0.796782506658028;0.731847886034993;0;0.0762293483775403;0.0305466933901674;0.00712070037305295;0.00895848266403771;0.0996922068539931;0.0926799260710134;0.257808317101151;0.101253771440299;-0.0576024019933660;0.0405094757406898;0.121620563951165;0.178093286965716];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-12) = 0;

% 2.5: -14816.0821
%     Results.HMXL_d.b0 = [0.0490817214760525;0.351961800824875;0.223548707727474;0.128320882853293;0.107683004313020;2.25908082661641;0.366316778484490;0.0167513352890771;0.0912032074386749;0.0640670575585782;0.0835099564980673;-0.928529554476395;0.0143210407690456;0.0355696982986390;0.0295189319460636;0.0122053753280252;0.000861468066363307;-0.183823802637404;-0.139312715987915;0.202360722988955;0.116094842259990;0.00848679304451667;0.0807718286201179;-0.0910854577951798;-0.0998554524235732;0.106272039987298;0.0572494378372263;0.00152911010232782;0.0545504004772185;-0.297971501131894;-5.23037985021269e-05;0.0504240336236783;-0.0320935409450041;0.00468337361594233;0.131012158635040;-0.234131485796310;0.244264325448854;0.100264821591707;0.0881397241806675;0.0295888146278921;-0.0128655507494418;-0.586818035357241;0.0739214608499992;0.0964873218316581;0.0163764406538351;-0.0741492782585366;-0.0517488478990547;-0.191940876981231;0.00841646683917743;0.0818508461823970;0.0905329333277695;-0.0638790134127090;0.0675548432290052;-0.0944491036412585;0.196065949937835;0.196756038875134;0.143435502683086;0.145702265681856;0.0754863067785718;-0.975905647082446;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;-0.100961622071202;-1.00807425881882;0.740378874447191;0.295280397482487;0.405195191237794;0.405097581296982;0.399719621479417;0.0575619536887335;-0.221522013138258;0.161076104167450;-0.112616487506499;-0.0932495367650644;-0.507437378250273;-1.73016865010813;1.71969827981236;-0.0793629027699461;-0.0745740136628449;0.727313687541884;0.557052154329755;0.310957451274881;-0.872461895214886;-0.218881098071807;-0.274107569195653;-0.488111752846228;0.136984948974624;0.481374195005632;-0.645486944127053;-0.0719291034923055;-0.0338730133834253;-0.264156707206425;-0.364581720045494;-0.0494590222843724;0.0188515707779974;-0.0390503690577667;0.270813598260745;0.114085092413105;0.188649355797605;-0.192104727637568;0.173839801340214;0.256694437469174;0.466636284027537;0.460300579155703;0.693391467830556;0.364529394582700;-0.308656734169343;-0.715992874194174;-0.196478247773975;-0.127235095911279;0.343505590201260;0.491411986321893;-0.415414576315469;-0.136695260467201;-0.0918475862957307;-0.387132843377221;-0.367636727704964;-0.109349368773350;0.466112184854953;0.210492690644759;0.108766618118060;0.309070237812225;0.205678939783683;-0.0288214275304825;0.0286108202890847;0.217091816854640;-0.244174189068765;0.0812029365419432;0.138155407345895;0.0996525470913488;0.115086011212245;0.151705424310943;-0.109448391567301;-0.0492345430997848;0.00559730932771254;0.00738798717180889;-1.64524512088303;-0.109949849963714;0.317134618207630;-0.0185894703052040;0.799071354132404;0.737387994749171;0;0.0757738443096973;0.0537714573093158;-0.0180437411348792;0.0106780602162482;0.103365267824343;0.0848047121759634;0.259464872092220;0.0972326101960693;-0.0527416866214382;0.0367240327043788;0.118821650445971;0.173525643795190];
%     EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
%     EstimOpt.BActive(end-12) = 0;

% +4.8: -14804.0474
% B_backup = [0.0431631036796570;0.340189915901245;0.222716672880014;0.124955522249217;0.0967156494544207;2.24822441237715;0.388043009215365;0.0243787370049172;0.0645481418075961;0.103348201057290;0.116450361551517;-0.579276290830923;0.0193717392113848;0.0291564663451123;0.0314895251127616;0.00870647260951019;-0.00608140284638449;-0.175126089796010;-0.0623673665702247;0.250952695395177;0.166254487301156;0.0393049227298849;0.0936203569385073;-0.179701963534835;0.0974546686902345;-0.0987603237944741;-0.0516152006732557;-0.00505396786283816;-0.0522818485793811;0.289219658010399;0.275572616921745;0.275016747930383;0.187728812563147;-0.00944656745136328;-0.0209587096235802;-1.48806442780316;-0.285941300372487;0.155359927408974;-0.118445697114450;-0.158286552376844;0.285267743998524;-0.782441188812839;-0.249499862978932;0.218561461373261;-0.109926204864772;-0.372818884997473;-0.00359645958021870;0.710772374691785;0.125382558480688;0.0546232561734038;0.144254328038188;0.118696093396963;-0.0224304205864945;-1.75061465579312;0.0713406993831679;0.0949665941058143;-0.0248878919275633;0.0565143221044619;0.0205810576241146;-0.534952387135938;-0.00627237809939597;-0.131720077887966;-0.0304668124626293;-0.156383912850771;-0.303882460509819;1.16108355163067;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;-0.518617278666634;-1.67000330014540;1.36215249522368;-0.0234806362568812;0.130115163643587;1.04650684018823;0.951479311566323;0.602818329534938;-1.29819848695452;-0.912220006264898;-0.273664589591301;-0.660006604811294;-3.48477400380223;-4.27060646388213;2.89782219413263;0.696360080422085;0.359980985302604;3.04037964716376;3.15532818302316;-1.56221841437044;-1.94753793346296;-1.51965674793650;-0.871343347025832;-3.23445371946137;2.47127937258739;3.80168722336550;-3.16760204825249;0.0348585829440887;0.273281673204093;-2.15204428492280;-1.97638781330367;0.388411802176796;1.93771127635892;0.803708971459412;0.646287546244479;2.16060418628031;0.896667060845044;1.92527073937790;-1.47134915609260;-0.00283205066215834;-0.0680687681563344;-1.31038838220240;-1.12991931288807;-0.842870990241596;1.78648756141211;0.714830146911496;0.266787282396439;0.904577717078453;-0.181103913454349;0.204908841350574;-0.263383604336735;-0.386391790141242;-0.533898785148177;-0.534096073218540;-0.866525835253729;-0.239848818334319;0.105727179505727;0.863887673323040;0.396251247141937;0.132166879848584;-1.64005046843800;-0.612347390100302;0.324609485847244;-0.211461284496710;-0.634454227844225;0.620459218660734;0.450305544021041;-1.04162301576415;-0.572378576519829;-0.424708174047720;-0.0433707264324964;-1.31135252423740;0.156061834999149;-0.0930457651623961;-0.0317209065691472;0.0280234805435851;0.205200342860823;-0.235046937360325;0.0822928813558290;0.138584211442809;0.100993547837607;0.113560183110242;0.155691770085086;-0.115450147937612;-0.0466757873937550;0.00457716442377069;0.00727488210750750;-1.63353276249722;-0.118016131177087;0.313318991616919;-0.0213586394319752;0.799499882836465;-0.735316537441735;0;0.0733577769083410;0.0281522121086035;0.00329752451037174;0.0136072871140378;0.108889983655128;0.0853503716569027;0.259712865391778;0.0901391487431202;-0.0522360309835088;0.0409392841623779;0.121771591287472;0.176250905560581];
% 6500: -14810.1510
% B_backup = [0.0509546780008050;0.338736766565482;0.218757719868560;0.132208351344644;0.100549383755162;2.25006291086986;0.394197979969810;-0.00806821643444292;0.0448100308068392;0.0856443069859537;0.0982808637399393;0.570699378348798;0.0177558448859082;0.0391537383995122;0.0306848333388462;0.0143166152049840;0.00125904733924527;-0.192232867376705;-0.0817989183211089;0.258812435093534;0.158406989891496;0.0216553679564769;0.0865242779270053;-0.0828822224162143;-0.0938927042229777;0.0930240029941105;0.0532971670348624;0.000455918405729581;0.0424186159614367;-0.273468376278679;2.46879524867389;2.52872502866160;1.70523169814727;-0.0273111665760722;-0.373837242373153;-15.7852573756786;-8.36543105967747;19.4604090873206;7.75633778840003;1.83403008069637;40.2768329176114;-66.7190581212985;-11.4992153040078;2.97877811232497;1.36992681332515;-9.92655414783629;1.44478645657184;10.6044675731584;9.68627396935777;4.16661350067396;10.0421259138073;13.5658762429699;-2.72095213966608;-90.9743931051787;-0.638790342042524;1.87819796345661;-2.59657685214102;0.144019177097840;1.09527447794535;-14.3941806559246;-9.67658298189704;-20.0392337878033;-12.1409416754058;-25.5622750663034;-37.5839270172938;167.016901863467;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;11.8366236868710;11.8212164960802;-9.78655957676443;-3.36136974927683;1.55638281488040;-5.19796467183676;-7.65435191326251;1.98292908457442;7.07320909454134;4.10908187436503;4.48622303873467;11.3841363269590;-295.240167325351;-311.385829463729;257.565076354686;80.9094152266078;-36.3079026738438;139.523633748250;198.729163906158;-31.7344540586864;-197.688815942829;-114.006691717268;-110.895217809680;-285.468090937871;119.137702225370;125.649934702837;-104.107138404413;-31.8545466468128;15.4293960911654;-56.1729026021018;-79.3927978407358;11.3552645416559;81.0006726671720;45.3714570218439;44.2153453198979;114.848662438638;-80.3133935379713;-83.8509758899337;69.4354887837948;21.8951933877483;-10.2541865511295;37.2735251500137;53.4960340743842;-9.75387881385386;-52.6094606382676;-30.5964463971330;-30.1907455147429;-77.6185066467145;-21.0195238069694;-21.8974839349529;17.9625990583572;5.76005222016823;-2.65977517701961;9.57366668709135;13.6744279766476;-2.91277613714199;-13.4626148642193;-7.63823626356586;-7.71620996480253;-20.2482523927893;-191.583418156232;-200.575927868544;165.831070541478;52.0997201398317;-24.1384095050217;89.8857782670891;128.128393654501;-21.0191129380170;-127.904451859413;-73.8188356191614;-71.6032616478369;-185.154285499364;0.172247403208419;0.0879995077755281;-0.0287931843306059;0.0284584383733601;0.193646502248492;-0.222548194280081;0.0836136345532767;0.142782192893385;0.104161231494720;0.119230214468233;0.142417716356732;-0.103185724882372;-0.0470473700349936;0.000466080635199219;0.00900488618211628;-1.63629178643552;-0.115750867160731;0.315394913811847;-0.0194267691813481;0.793437076484036;0.736595388442308;0;0.0726465991978858;-0.00639284190164674;0.0360880016979519;0.0155306326947168;0.117069651111571;0.0924927880565092;0.272965774753357;0.0675999130545145;-0.0310446319231998;0.0366630883602441;0.108350190109881;0.174069640816845];
% EstimOpt.BActive = ones(size(Results.HMXL_d.b0));
% EstimOpt.BActive(end-12) = 0;


Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);